CArcArrayBuilder

Struct CArcArrayBuilder 

pub struct CArcArrayBuilder<T, TAllocator: Allocator> { /* private fields */ }
This is a builder for CArcArray. It is used to iteratively construct a CArcArray, without the need of intermediate allocations.

Implementations

Source

impl<T, TAllocator: Allocator> CArcArrayBuilder<T, TAllocator>

pub fn new() -> Result<Self, CArcArrayError>
where TAllocator: Default,

Creates a new CArcArrayBuilder with the default allocator.

Notes

This function allocates memory.

Errors

For details see CArcArrayError.

pub fn with_capacity(capacity: Length) -> Result<Self, CArcArrayError>
where TAllocator: Default,

Creates a new CArcArrayBuilder with the given capacity and the default allocator.

Notes

This function allocates memory.

Errors

For details see CArcArrayError.

pub fn with_capacity_and_allocator( capacity: Length, allocator: TAllocator, ) -> Result<Self, CArcArrayError>

Creates a new CArcArrayBuilder with the given capacity and allocator.

Notes

This function allocates memory.

Errors

For details see CArcArrayError.

pub fn try_push_slice(&mut self, slice: &[T]) -> Result<(), CArcArrayError>
where T: Clone,

Pushes a new slice to the CArcArrayBuilder.

Notes

This function clones the data.

Errors

For details see CArcArrayError.

pub fn try_push_array<const N: usize>( &mut self, array: [T; N], ) -> Result<(), CArcArrayError>

Pushes a new array to the CArcArrayBuilder.

Notes

This function moves the data.

Errors

For details see CArcArrayError.

pub fn shrink_to_fit(&mut self) -> Result<(), CArcArrayError>

Shrinks the underlying buffer to match the length of the buffer exactly.

Notes

This function may reallocate the underlying buffer, depending on the allocator’s behavior.

Errors

For details see CArcArrayError.

pub fn build(self) -> CArcArray<T, TAllocator>

Builds a new CArcArray out of the CArcArrayBuilder.